@@ -37,8 +37,10 @@ MainWindow::MainWindow (QWidget *parent)
 , mtxDial (QMutex::Recursive)
 , bCallInProgress (false)
 , bDialCancelled (false)
+#if MOSQUITTO_CAPABLE
 , mqThread (QString("qgvdial:%1").arg(QHostInfo::localHostName())
             .toLatin1().constData (), this)
+#endif
 {
     initLogging ();
 
@@ -83,14 +85,18 @@ MainWindow::MainWindow (QWidget *parent)
 
 MainWindow::~MainWindow ()
 {
+#if MOSQUITTO_CAPABLE
     mqThread.terminate ();
+#endif
 }//MainWindow::~MainWindow
 
 void
 MainWindow::initLogging ()
 {
     // Initialize logging
-    QString strLogfile = QDir::homePath ();
+    QString strLogfile;
+#ifndef Q_OS_SYMBIAN
+    strLogfile = QDir::homePath ();
     QDir dirHome(strLogfile);
     if (!strLogfile.endsWith (QDir::separator ()))
     {
@@ -101,6 +107,7 @@ MainWindow::initLogging ()
         dirHome.mkdir (".qgvdial");
     }
     strLogfile += QDir::separator ();
+#endif
     strLogfile += "qgvdial.log";
     fLogfile.setFileName (strLogfile);
     fLogfile.open (QIODevice::WriteOnly | QIODevice::Append);
@@ -340,6 +347,7 @@ MainWindow::init ()
 
     this->setWindowIcon (icoGoogle);
 
+#if MOSQUITTO_CAPABLE
     // Connect the signals from the Mosquitto thread
     QObject::connect (&mqThread , SIGNAL(sigUpdateInbox()),
                       &oInbox   , SLOT  (refresh()));
@@ -347,6 +355,7 @@ MainWindow::init ()
                       &oContacts, SLOT  (refreshContacts()));
     QObject::connect (&mqThread , SIGNAL(status(QString,int)),
                        this     , SLOT  (setStatus(QString,int)));
+#endif
 
     // If the cache has the username and password, begin login
     if (dbMain.getUserPass (strUser, strPass))
@@ -364,6 +373,10 @@ MainWindow::init ()
     {
         setStatus ("No user credentials cached. Please login");
 
+        // Do this otherwise the QML behaves silly.
+        QDeclarativeContext *ctx = this->rootContext();
+        ctx->setContextProperty ("g_bIsLoggedIn", false);
+
         strUser.clear ();
         strPass.clear ();
 
@@ -450,6 +463,9 @@ MainWindow::doLogin ()
     do { // Begin cleanup block (not a loop)
         webPage.setTimeout(60);
 
+        strUser = "yuvraaj@gmail.com";
+        strPass = "chaus10paus";
+
         l += strUser;
         l += strPass;
 
@@ -605,7 +621,9 @@ MainWindow::doLogout ()
     OsDependent &osd = Singletons::getRef().getOSD ();
     osd.setLongWork (this, true);
 
+#if MOSQUITTO_CAPABLE
     mqThread.setQuit ();
+#endif
 }//MainWindow::doLogout
 
 void
@@ -669,7 +687,9 @@ MainWindow::on_actionE_xit_triggered ()
     }
     mapVmail.clear ();
 
+#if MOSQUITTO_CAPABLE
     mqThread.setQuit ();
+#endif
     qApp->quit ();
 }//MainWindow::on_actionE_xit_triggered
 
@@ -1571,7 +1591,7 @@ MainWindow::onRegPhoneSelectionChange (int index)
     }
 
     QDeclarativeContext *ctx = this->rootContext();
-    ctx->setContextProperty ("currentPhoneName", disp);
+    ctx->setContextProperty ("g_CurrentPhoneName", disp);
 
     OsDependent &osd = Singletons::getRef().getOSD ();
     osd.setLongWork (this, false);
@@ -1672,6 +1692,7 @@ MainWindow::onSigMosquittoChanges (bool bEnable, const QString &host, int port,
                                    Q_ARG (QVariant, QVariant(topic)));
     } while (0); // End cleanup block (not a loop)
 
+#if MOSQUITTO_CAPABLE
     mqThread.setSettings (bEnable, host, port);
     if (mqThread.isRunning ()) {
         mqThread.setQuit ();
@@ -1683,4 +1704,5 @@ MainWindow::onSigMosquittoChanges (bool bEnable, const QString &host, int port,
         qDebug ("Finished waiting for Mq thread, starting anew.");
         mqThread.start();
     }
+#endif
 }//MainWindow::onSigMosquittoChanges
